@@ -31,6 +31,36 @@ class UpgradeDBInstanceRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_InstanceSpec(self): # String
+		return self.get_query_params().get('InstanceSpec')
+
+	def set_InstanceSpec(self, InstanceSpec):  # String
+		self.add_query_param('InstanceSpec', InstanceSpec)
+	def get_StorageSize(self): # String
+		return self.get_query_params().get('StorageSize')
+
+	def set_StorageSize(self, StorageSize):  # String
+		self.add_query_param('StorageSize', StorageSize)
+	def get_MasterNodeNum(self): # String
+		return self.get_query_params().get('MasterNodeNum')
+
+	def set_MasterNodeNum(self, MasterNodeNum):  # String
+		self.add_query_param('MasterNodeNum', MasterNodeNum)
+	def get_UpgradeType(self): # Long
+		return self.get_query_params().get('UpgradeType')
+
+	def set_UpgradeType(self, UpgradeType):  # Long
+		self.add_query_param('UpgradeType', UpgradeType)
+	def get_ResourceGroupId(self): # String
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
+	def get_SegNodeNum(self): # String
+		return self.get_query_params().get('SegNodeNum')
+
+	def set_SegNodeNum(self, SegNodeNum):  # String
+		self.add_query_param('SegNodeNum', SegNodeNum)
 	def get_DBInstanceId(self): # String
 		return self.get_query_params().get('DBInstanceId')
 
